@@ -171,7 +171,7 @@ static const quint64 k_BZip2 = 0x040202;
 // static const quint64 k_Bzip2NSIS = 0x040902;
 static const quint64 k_AES = 0x06F10701;
 
-/**
+/*!
  * A K7ZipFileEntry represents a file in a 7zip archive.
  */
 class K7ZipFileEntry : public KArchiveFile
@@ -190,13 +190,13 @@ public:
 
     ~K7ZipFileEntry() override;
 
-    /**
-     * @return the content of this file.
+    /*!
+     * Returns the content of this file.
      * Call data() with care (only once per file), this data isn't cached.
      */
     QByteArray data() const override;
 
-    /**
+    /*!
      * This method returns QIODevice (internal class: KLimitedIODevice)
      * on top of the underlying QIODevice. This is obviously for reading only.
      *
@@ -204,7 +204,7 @@ public:
      * who will have to delete it.
      *
      * The returned device auto-opens (in readonly mode), no need to open it.
-     * @return the QIODevice of the file
+     * Returns the QIODevice of the file
      */
     QIODevice *createDevice() const override;
 
@@ -978,6 +978,9 @@ bool K7Zip::K7ZipPrivate::readUnpackInfo()
 
     for (int i = 0; i < numFolders; ++i) {
         Folder *folder = folders.at(i);
+        if (!folder) {
+            continue;
+        }
         int numOutStreams = folder->getNumOutStreams();
         for (int j = 0; j < numOutStreams; ++j) {
             folder->unpackSizes.append(readNumber());
@@ -985,6 +988,10 @@ bool K7Zip::K7ZipPrivate::readUnpackInfo()
     }
 
     for (;;) {
+        if (pos >= end) {
+            return false;
+        }
+
         int type = readByte();
         if (type == kEnd) {
             break;
